@@ -20,37 +20,37 @@ def cut(video_path, data_home):
     video.load_frames()
 
     cutter = VideoCutter()
-    res = cutter.cut(video)
-    stable, unstable = res.get_range(offset=3)
+    res = cutter.cut(video, block=6)
+    stable, unstable = res.get_range(threshold=0.97, offset=3)
 
     # save dataset
     res.pick_and_save(stable, 10, to_dir=data_home, meaningful_name=True)
     print(f"data saved to {data_home}")
 
 
-def train(data_home, loop):
+def train(data_home, loop: int, target_size: tuple, model_file='keras_model.h5'):
     """
 
+    :param model_file:
+    :param target_size: (888,1920)
     :param loop: 训练循环次数
     :param data_home: data_home = "./dataset"
     :return:
     """
 
-    model_file = "./keras_model.h5"
-
     cl = KerasClassifier(
-        # 轮数
-        epochs=int(loop),
-        # 保证数据集的分辨率统一性
-        target_size=(888, 1920),
+        epochs=loop,
+        target_size=target_size,
     )
     cl.train(data_home)
-    cl.save_model(model_file, overwrite=True)
+    cl.save_model(model_path=model_file, overwrite=True)
 
 
-def predict(video_path, model_file):
+def predict(video_path, model_file, target_size: tuple, report_path='report.html'):
     """
 
+    :param report_path:
+    :param target_size: (888,1920)
     :param video_path: test.mp4
     :param model_file: ./keras_model.h5
     :return:
@@ -67,8 +67,7 @@ def predict(video_path, model_file):
 
     # --- classifier ---
     cl = KerasClassifier(
-        # 在使用时需要保证数据集格式统一（与训练集）
-        target_size=(888, 1920),
+        target_size=target_size
     )
 
     cl.load_model(model_file)
@@ -78,5 +77,5 @@ def predict(video_path, model_file):
 
     # --- draw ---
     r = Reporter()
-    r.draw(classify_result, report_path='report.html')
+    r.draw(classify_result, report_path=report_path)
     return result_dict
